@@ -5,10 +5,10 @@ joint_estimate <- function(net_object                                 ,
                            mode_reg_A     = 0                         ,
                            ...) {
   
-  if (class(net_object) != "PAFit_net")
+  if (!is(net_object,"PAFit_net"))
     stop("net_object should be of PAFit_net class.")
   
-  if (class(net_stat) != "PAFit_data")
+  if (!is(net_stat,"PAFit_data"))
     stop("Please input a proper net summary of class PAFit_data");
   
   # quick check 
@@ -26,7 +26,7 @@ joint_estimate <- function(net_object                                 ,
   # first finding the optima r and s by cross validation
   
   deg_thresh     <- net_stat$deg_thresh
-  cv_deg_thresh  <- c(0);
+  cv_deg_thresh  <- c(1);
   
   #net_type       <- net_stat$net_type
   #raw_net_object <- as.PAFit_net(graph = raw_net, type = net_type)
