@@ -9,9 +9,9 @@ summary.PAFit_data <- function(object,...){
   }
   cat("Number of new nodes:",length(object$final_deg) - object$initial_nodes,"\n")
   if (object$net_type[1] == "directed") {
-    cat("Number of edges in the final network:",sum(object$final_deg),"\n")
+    cat("Number of new edges:", sum(object$sum_m_k) + sum(object$offset_m_tk),"\n")
   } else {
-      cat("Number of new edges:",sum(object$sum_m_k)/2, "\n")
+      cat("Number of new edges:", sum(object$sum_m_k) + sum(object$offset_m_tk), "\n")
   }
   cat("Number of time-steps:",  object$T,"\n");
   if ("directed" == object$net_type[1]) {
